# <img src="docs/_static/tart.svg" alt="tart logo" height="52" align="absbottom" align="left"> [`tart`](): tensor abstracted relations and topologies

[![pytest](https://github.com/tart-proj/tart/actions/workflows/pytest.yml/badge.svg)](https://github.com/tart-proj/tart/actions/workflows/pytest.yml)
[![Documentation Status](https://readthedocs.org/projects/tart/badge/?version=latest)](https://tart.readthedocs.io/en/latest/?badge=latest)


Contributors: [Manish Shetty](https://manishs.org), [Koushik Sen](https://people.eecs.berkeley.edu/~ksen)
